<?php
/**
 * Portfolio Icon Lite Theme Options
 *
 * @package Portfolio Icon Lite
 */

/**
 * Add theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function portfolioicon_theme_options( $wp_customize ) {
	$wp_customize->add_panel( 'portfolioicon_theme_options', array(
        'title'    => esc_html__( 'Theme Options', 'portfolio-icon-lite' ),
        'priority' => 130,
    ) );

    // Breadcrumb Option
    $wp_customize->add_section( 'portfolioicon_breadcrumb_options', array(
        'description'   => esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'portfolio-icon-lite' ),
        'panel'         => 'portfolioicon_theme_options',
        'title'         => esc_html__( 'Breadcrumb', 'portfolio-icon-lite' ),
    ) );

    $wp_customize->add_setting( 'portfolioicon_breadcrumb_option', array(
        'default'           => 1,
        'sanitize_callback' => 'portfolioicon_sanitize_checkbox'
    ) );

    $wp_customize->add_control( 'portfolioicon_breadcrumb_option', array(
        'label'    => esc_html__( 'Check to enable Breadcrumb', 'portfolio-icon-lite' ),
        'section'  => 'portfolioicon_breadcrumb_options',
        'type'     => 'checkbox',
    ) );
    // Breadcrumb Option End

    $wp_customize->add_section( 'portfolioicon_header_media_options', array(
        'title' => esc_html__( 'First Section', 'portfolio-icon-lite' ),
        'panel' => 'portfolioicon_theme_options'
    ) );

    $wp_customize->add_setting( 'portfolioicon_header_media_text', array(
        'default'           => esc_html__( 'This is Header Media Text.', 'portfolio-icon-lite' ),
        'sanitize_callback' => 'wp_kses_post',
    ) );

    $wp_customize->add_control( 'portfolioicon_header_media_text', array(
        'label'   => esc_html__( 'Header Media Text', 'portfolio-icon-lite' ),
        'section' => 'portfolioicon_header_media_options',
        'type'    => 'textarea',
    ) );

    $wp_customize->add_section( 'portfolioicon_menu_options', array(
        'title' => esc_html__( 'Menu Options', 'portfolio-icon-lite' ),
        'panel' => 'portfolioicon_theme_options'
    ) );

    /* Menu Type */
    $wp_customize->add_setting( 'portfolioicon_menu_type', array(
        'default'           => 'default',
        'sanitize_callback' => 'portfolioicon_sanitize_select',
    ) );

    $wp_customize->add_control( 'portfolioicon_menu_type', array(
        'label'    => esc_html__( 'Menu Type', 'portfolio-icon-lite' ),
        'section'  => 'portfolioicon_menu_options',
        'type'     => 'radio',
        'choices'  => array(
            'default' => esc_html__( 'Default', 'portfolio-icon-lite' ),
            'classic' => esc_html__( 'Classic', 'portfolio-icon-lite' ),
        ),
    ) );

    $wp_customize->add_section( 'portfolioicon_layout_options', array(
        'title' => esc_html__( 'Single Page Layout', 'portfolio-icon-lite' ),
        'panel' => 'portfolioicon_theme_options'
    ) );

    /* Default Layout */
    $wp_customize->add_setting( 'portfolioicon_default_layout', array(
        'default'           => 'no-sidebar',
        'sanitize_callback' => 'portfolioicon_sanitize_select',
    ) );

    $wp_customize->add_control( 'portfolioicon_default_layout', array(
        'description'       => esc_html__( 'Layout for Singular Post Types like Post, Page', 'portfolio-icon-lite' ),
         'label'    => esc_html__( 'Singular Content Layout', 'portfolio-icon-lite' ),
        'section'  => 'portfolioicon_layout_options',
        'type'     => 'radio',
        'choices'  => array(
            'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'portfolio-icon-lite' ),
            'no-sidebar'            => esc_html__( 'No Sidebar', 'portfolio-icon-lite' ),
        ),
    ) );

    // Excerpt Options
    $wp_customize->add_section( 'portfolioicon_excerpt_options', array(
        'panel'     => 'portfolioicon_theme_options',
        'title'     => esc_html__( 'Excerpt Options', 'portfolio-icon-lite' ),
    ) );

    $wp_customize->add_setting( 'portfolioicon_excerpt_length', array(
        'default'           => '30',
        'sanitize_callback' => 'absint',
    ) );

    $wp_customize->add_control( 'portfolioicon_excerpt_length', array(
        'description' => esc_html__('Excerpt length. Default is 30 words', 'portfolio-icon-lite'),
        'input_attrs' => array(
            'min'   => 10,
            'max'   => 200,
            'step'  => 5,
            'style' => 'width: 60px;'
            ),
        'label'    => esc_html__( 'Excerpt Length (words)', 'portfolio-icon-lite' ),
        'section'  => 'portfolioicon_excerpt_options',
        'type'     => 'number',
        )
    );

    $wp_customize->add_setting( 'portfolioicon_excerpt_more_text', array(
        'default'           => esc_html__( 'Continue reading', 'portfolio-icon-lite' ),
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( 'portfolioicon_excerpt_more_text', array(
        'label'    => esc_html__( 'Read More Text', 'portfolio-icon-lite' ),
        'section'  => 'portfolioicon_excerpt_options',
        'type'     => 'text',
    ) );
    // Excerpt Options End

    //Homepage / Frontpage Options
    $wp_customize->add_section( 'portfolioicon_homepage_options', array(
        'description' => esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'portfolio-icon-lite' ),
        'panel'       => 'portfolioicon_theme_options',
        'title'       => esc_html__( 'Homepage Options', 'portfolio-icon-lite' ),
    ) );

    $wp_customize->add_setting( 'portfolioicon_front_page_category', array(
        'default'           => array(),
        'sanitize_callback' => 'portfolioicon_sanitize_category_list',
    ) );

    $wp_customize->add_control( new PortfolioIconLiteCustomizeDropdownCategoriesControl( $wp_customize, 'portfolioicon_front_page_category', array(
        'label'             => esc_html__( 'Select Categories', 'portfolio-icon-lite' ),
        'name'              => 'portfolioicon_front_page_category',
        'section'           => 'portfolioicon_homepage_options',
        'type'              => 'dropdown-categories',
    ) ) );

    // Disable Recent post in static frontpage
    $wp_customize->add_setting( 'portfolioicon_enable_static_page_posts', array(
        'sanitize_callback' => 'portfolioicon_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'portfolioicon_enable_static_page_posts', array(
        'label'           => esc_html__( 'Check to Enable Recent Posts on Static Frontpage', 'portfolio-icon-lite' ),
        'section'         => 'portfolioicon_homepage_options',
        'type'            => 'checkbox',
    ) );
    //Homepage / Frontpage Settings End


    // Pagination Options
    $nav_desc = sprintf( esc_html__( 'Infinite Scroll Options requires %1$sJetPack Plugin%2$s with Infinite Scroll module Enabled.', 'portfolio-icon-lite' ), '<a target="_blank" href="' . esc_url( 'https://wordpress.org/plugins/jetpack/' ) . '">', '</a>' );

    $wp_customize->add_section( 'portfolioicon_pagination_options', array(
        'description'   => $nav_desc,
        'panel'         => 'portfolioicon_theme_options',
        'title'         => esc_html__( 'Pagination Options', 'portfolio-icon-lite' ),
    ) );

    $wp_customize->add_setting( 'portfolioicon_pagination_type', array(
        'default'           => 'default',
        'sanitize_callback' => 'portfolioicon_sanitize_select',
    ) );

    $wp_customize->add_control( 'portfolioicon_pagination_type', array(
        'choices'  => portfolioicon_get_pagination_types(),
        'label'    => esc_html__( 'Pagination type', 'portfolio-icon-lite' ),
        'section'  => 'portfolioicon_pagination_options',
        'type'     => 'select',
    ) );
    // Pagination Options End

    /* Scrollup Options */
    $wp_customize->add_section( 'portfolioicon_scrollup', array(
        'panel'    => 'portfolioicon_theme_options',
        'title'    => esc_html__( 'Scrollup Options', 'portfolio-icon-lite' ),
    ) );

    $wp_customize->add_setting( 'portfolioicon_disable_scrollup', array(
        'sanitize_callback' => 'portfolioicon_sanitize_checkbox',
    ) );

    $wp_customize->add_control( 'portfolioicon_disable_scrollup', array(
        'label'     => esc_html__( 'Check to disable Scroll Up', 'portfolio-icon-lite' ),
        'section'   => 'portfolioicon_scrollup',
        'type'      => 'checkbox',
    ) );
}
add_action( 'customize_register', 'portfolioicon_theme_options' );
